@@ -2,11 +2,11 @@ use strict;
 use warnings;
 use Carp;
 use SDL;
-use SDL::Video ;
+use SDL::Video;
 use SDL::Surface;
 use SDL::Rect;
 use SDL::Event;
-use SDL::Events ;
+use SDL::Events;
 use Data::Dumper;
 use Math::Trig;
 
@@ -24,7 +24,6 @@ my $paddle = {
     y_vel => 0,
 };
 
-
 my $paddle2 = {
     x     => $app->w - 20,
     y     => 0,
@@ -35,40 +34,39 @@ my $paddle2 = {
 };
 
 my $r_ball = {
-    x     => $app->w /2,
-    y     => $app->w /2,
+    x     => $app->w / 2,
+    y     => $app->w / 2,
     w     => 20,
     h     => 20,
-    x_vel => ( 150 ),
-    y_vel => ( 150 ),
+    x_vel => (150),
+    y_vel => (150),
 };
 
 sub ball_confine {
-    my ($w,$h,$x,$y, $ws, $hs) = @_;
+    my ( $w, $h, $x, $y, $ws, $hs ) = @_;
 
-    my ($m_x,$m_y) = (1,1);
+    my ( $m_x, $m_y ) = ( 1, 1 );
     $m_x = -1 if $x + $ws >= $w || $x <= 0;
     $m_y = -1 if $y + $hs >= $h || $y <= 0;
 
-    return [$m_x,$m_y];  
+    return [ $m_x, $m_y ];
 }
-      
+
 sub paddle_confine {
-       #return if $_[0]->{y_vel} == 0;
-       my ($p, $dt, $h) = @_;
-       if ($p->{y} < 0 )
-       {
-           $p->{y} = 2;
-           return;
-       }
-       elsif ( $p->{y} + $p->{h} + 2 > $h)
-       {
-           $p->{y} = $h - $p->{h} -2;
-           return;
-       }
-       
-       $p->{y} += $p->{y_vel} * $dt;
-}      
+
+    #return if $_[0]->{y_vel} == 0;
+    my ( $p, $dt, $h ) = @_;
+    if ( $p->{y} < 0 ) {
+        $p->{y} = 2;
+        return;
+    }
+    elsif ( $p->{y} + $p->{h} + 2 > $h ) {
+        $p->{y} = $h - $p->{h} - 2;
+        return;
+    }
+
+    $p->{y} += $p->{y_vel} * $dt;
+}
 
 sub init {
 
@@ -88,29 +86,33 @@ sub init {
     return $a;
 }
 
-my $game = SDLx::Controller->new( dt=> 0.1);
+my $game = SDLx::Controller->new( dt => 0.1 );
 
 sub on_move {
     my $dt = shift;
     $dt = $dt / 1000;
-    paddle_confine($paddle, $dt, $app->h);
-    paddle_confine($paddle2, $dt, $app->h);
-    # Period = $r_ball->{vel}
-    
-    # cc_speed = 2 * pi * r / T 
-    
-    my $transform = ball_confine( $app->w, $app->h, $r_ball->{x} , $r_ball->{y},  $r_ball->{w}, $r_ball->{h} );
-    $r_ball->{x_vel } *= $transform->[0];
-    $r_ball->{y_vel } *= $transform->[1];
+    paddle_confine( $paddle,  $dt, $app->h );
+    paddle_confine( $paddle2, $dt, $app->h );
 
-    $r_ball->{x} += $r_ball->{x_vel } * $dt;
-    $r_ball->{y} += $r_ball->{y_vel } * $dt;
+    # Period = $r_ball->{vel}
+
+    # cc_speed = 2 * pi * r / T
+
+    my $transform = ball_confine(
+        $app->w,      $app->h,      $r_ball->{x},
+        $r_ball->{y}, $r_ball->{w}, $r_ball->{h}
+    );
+    $r_ball->{x_vel} *= $transform->[0];
+    $r_ball->{y_vel} *= $transform->[1];
+
+    $r_ball->{x} += $r_ball->{x_vel} * $dt;
+    $r_ball->{y} += $r_ball->{y_vel} * $dt;
 
     # "AI" for the other paddle
-    if ($r_ball->{y} > $paddle2->{y}) {
+    if ( $r_ball->{y} > $paddle2->{y} ) {
         $paddle2->{y_vel} = $paddle2->{vel};
     }
-    elsif ($r_ball->{y} < $paddle2->{y}) {
+    elsif ( $r_ball->{y} < $paddle2->{y} ) {
         $paddle2->{y_vel} = -1 * $paddle2->{vel};
     }
     else {
@@ -125,16 +127,20 @@ sub on_event {
 
     if ( $event->type == SDL_KEYDOWN ) {
         my $key = $event->key_sym;
-		if($key == SDLK_PRINT)
-		{
-			my $screen_shot_index = 1;
-			map{$screen_shot_index = $1 + 1 if $_ =~ /Shot(\d+)\.bmp/ && $1 >= $screen_shot_index} <Shot*\.bmp>;
-			SDL::Video::save_BMP($app, sprintf("Shot%04d.bmp", $screen_shot_index ));
-		}
+        if ( $key == SDLK_PRINT ) {
+            my $screen_shot_index = 1;
+            map {
+                $screen_shot_index = $1 + 1
+                  if $_ =~ /Shot(\d+)\.bmp/
+                      && $1 >= $screen_shot_index
+            } <Shot*\.bmp>;
+            SDL::Video::save_BMP( $app,
+                sprintf( "Shot%04d.bmp", $screen_shot_index ) );
+        }
         $paddle->{y_vel} -= $paddle->{vel} if $key == SDLK_UP;
         $paddle->{y_vel} += $paddle->{vel} if $key == SDLK_DOWN;
         $r_ball->{rot_vel} += 50 if $key == SDLK_SPACE;
-     
+
     }
     elsif ( $event->type == SDL_KEYUP ) {
         my $key = $event->key_sym;
@@ -152,17 +158,19 @@ sub on_event {
 # New subroutine "show_paddle" extracted - Thu Mar 18 15:28:02 2010.
 #
 sub show_paddle {
-    my $app = shift;
+    my $app    = shift;
     my $paddle = shift;
 
     SDL::Video::fill_rect(
         $app,
-        SDL::Rect->new( $paddle->{x}, $paddle->{y}, $paddle->{w}, $paddle->{h} ),
+        SDL::Rect->new(
+            $paddle->{x}, $paddle->{y}, $paddle->{w}, $paddle->{h}
+        ),
         SDL::Video::map_RGB( $app->format, 0, 0, 255 )
     );
 
     return ();
-} 
+}
 
 sub on_show {
     SDL::Video::fill_rect(
@@ -170,19 +178,18 @@ sub on_show {
         SDL::Rect->new( 0, 0, $app->w, $app->h ),
         SDL::Video::map_RGB( $app->format, 0, 0, 0 )
     );
-    
-    
-    show_paddle ($app, $paddle);
-    
-    show_paddle ($app, $paddle2);
-    
+
+    show_paddle( $app, $paddle );
+
+    show_paddle( $app, $paddle2 );
+
     SDL::Video::fill_rect(
         $app,
-        SDL::Rect->new( $r_ball->{x}, $r_ball->{y}, $r_ball->{w}, $r_ball->{h} ),
+        SDL::Rect->new(
+            $r_ball->{x}, $r_ball->{y}, $r_ball->{w}, $r_ball->{h}
+        ),
         SDL::Video::map_RGB( $app->format, 255, 0, 0 )
     );
-    
-    
 
     SDL::Video::flip($app);
 
