@@ -36,65 +36,66 @@ use Carp;
 use SDL;
 
 sub new {
-	my $proto   = shift;
-	my $class   = ref($proto) || $proto;
-	my %options = @_;
+    my $proto   = shift;
+    my $class   = ref($proto) || $proto;
+    my %options = @_;
 
-	my $self;
-	if ( $options{-from} ) {
-		Carp::confess "SDL::MPEG::new -from requires a SDL::Video object\n"
-			unless $options{-from}->isa('SDL::Video');
+    my $self;
+    if ( $options{-from} ) {
+        croak "SDL::MPEG::new -from requires a SDL::Video object\n"
+          unless $options{-from}->isa('SDL::Video');
 
-		$self = \SDL::SMPEGGetInfo( ${ $options{-from} } );
-	} else {
-		$self = \SDL::NewSMPEGInfo();
-	}
-	bless $self, $class;
-	return $self;
+        $self = \SDL::SMPEGGetInfo( ${ $options{-from} } );
+    }
+    else {
+        $self = \SDL::NewSMPEGInfo();
+    }
+    bless $self, $class;
+    return $self;
 }
 
 sub DESTROY {
-	SDL::FreeSMPEGInfo( ${ $_[0] } );
+    SDL::FreeSMPEGInfo( ${ $_[0] } );
 }
 
 sub has_audio {
-	SDL::SMPEGInfoHasAudio( ${ $_[0] } );
+    SDL::SMPEGInfoHasAudio( ${ $_[0] } );
 }
 
 sub has_video {
-	SDL::SMPEGInfoHasVideo( ${ $_[0] } );
+    SDL::SMPEGInfoHasVideo( ${ $_[0] } );
 }
 
 sub width {
-	SDL::SMPEGInfoWidth( ${ $_[0] } );
+    SDL::SMPEGInfoWidth( ${ $_[0] } );
 }
 
 sub height {
-	SDL::SMPEGInfoHeight( ${ $_[0] } );
+    SDL::SMPEGInfoHeight( ${ $_[0] } );
 }
 
 sub size {
-	SDL::SMPEGInfoTotalSize( ${ $_[0] } );
+    SDL::SMPEGInfoTotalSize( ${ $_[0] } );
 }
 
 sub offset {
-	SDL::SMPEGInfoCurrentOffset( ${ $_[0] } );
+    SDL::SMPEGInfoCurrentOffset( ${ $_[0] } );
 }
 
 sub frame {
-	SDL::SMPEGInfoCurrentFrame( ${ $_[0] } );
+    SDL::SMPEGInfoCurrentFrame( ${ $_[0] } );
 }
 
 sub fps {
-	SDL::SMPEGInfoCurrentFPS( ${ $_[0] } );
+    SDL::SMPEGInfoCurrentFPS( ${ $_[0] } );
 }
 
 sub time {
-	SDL::SMPEGInfoCurrentTime( ${ $_[0] } );
+    SDL::SMPEGInfoCurrentTime( ${ $_[0] } );
 }
 
 sub length {
-	SDL::SMPEGInfoTotalTime( ${ $_[0] } );
+    SDL::SMPEGInfoTotalTime( ${ $_[0] } );
 }
 
 1;
