@@ -1,16 +1,12 @@
 package SDL::Net;
 use strict;
 use warnings;
-use vars qw($VERSION $XS_VERSION @ISA @EXPORT @EXPORT_OK);
+use vars qw(@ISA @EXPORT @EXPORT_OK);
 require Exporter;
 require DynaLoader;
 use SDL::Constants ':SDL::Net';
 our @ISA = qw(Exporter DynaLoader);
 
-our $VERSION    = '2.541_10';
-our $XS_VERSION = $VERSION;
-$VERSION = eval $VERSION;
-
 use SDL::Internal::Loader;
 internal_load_dlls(__PACKAGE__);
 
@@ -19,8 +15,8 @@ bootstrap SDL::Net;
 use base 'Exporter';
 our @EXPORT      = @{ $SDL::Constants::EXPORT_TAGS{'SDL::Net'} };
 our %EXPORT_TAGS = (
-	all      => \@EXPORT,
-	defaults => $SDL::Constants::EXPORT_TAGS{'SDL::Net/defaults'}
+    all      => \@EXPORT,
+    defaults => $SDL::Constants::EXPORT_TAGS{'SDL::Net/defaults'}
 );
 
 1;
