@@ -10,12 +10,12 @@
 # modify it under the terms of the GNU Lesser General Public
 # License as published by the Free Software Foundation; either
 # version 2.1 of the License, or (at your option) any later version.
-# 
+#
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 # Lesser General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -34,17 +34,17 @@ use strict;
 use warnings;
 
 use SDL;
-use SDL::App;
+use SDLx::App;
 
 # change these values as necessary
-my  $title                   = 'My SDL App';
-my ($width, $height, $depth) = ( 640, 480, 16 );
+my $title = 'My SDL App';
+my ( $width, $height, $depth ) = ( 640, 480, 16 );
 
-my $app = SDL::App->new(
-	-width  => $width,
-	-height => $height,
-	-depth  => $depth,
-	-title  => $title,
+my $app = SDLx::App->new(
+    -width  => $width,
+    -height => $height,
+    -depth  => $depth,
+    -title  => $title,
 );
 
 # your code here; remove the next line
